@@ -157,6 +157,11 @@ handle_user_command(struct vsf_session* p_sess)
     str_empty(&p_sess->user_str);
     return;
   }
+  if (!tunable_anonymous_enable && is_anon)
+  {
+    vsf_cmdio_write(
+      p_sess, FTP_LOGINERR, "This FTP server does not allow anonymous logins.");
+  }
   if (is_anon && p_sess->control_use_ssl && !tunable_allow_anon_ssl &&
       !tunable_force_anon_logins_ssl)
   {
